<html>
    <head>
        <title>Une valeur Request.Form potentiellement dangereuse a &#233;t&#233; d&#233;tect&#233;e &#224; partir du client (DateDeb=&quot;&amp;#9731;&quot;).</title>
        <style>
        	body {font-family:"Verdana";font-weight:normal;font-size: .7em;color:black;} 
        	p {font-family:"Verdana";font-weight:normal;color:black;margin-top: -5px}
        	b {font-family:"Verdana";font-weight:bold;color:black;margin-top: -5px}
        	H1 { font-family:"Verdana";font-weight:normal;font-size:18pt;color:red }
        	H2 { font-family:"Verdana";font-weight:normal;font-size:14pt;color:maroon }
        	pre {font-family:"Lucida Console";font-size: .9em}
        	.marker {font-weight: bold; color: black;text-decoration: none;}
        	.version {color: gray;}
        	.error {margin-bottom: 10px;}
        	.expandable { text-decoration:underline; font-weight:bold; color:navy; cursor:hand; }
        </style>
    </head>

    <body bgcolor="white">

            <span><H1>Erreur du serveur dans l'application '/'.<hr width=100% size=1 color=silver></H1>

            <h2> <i>Une valeur Request.Form potentiellement dangereuse a &#233;t&#233; d&#233;tect&#233;e &#224; partir du client (DateDeb=&quot;&amp;#9731;&quot;).</i> </h2></span>

            <font face="Arial, Helvetica, Geneva, SunSans-Regular, sans-serif ">

            <b> Description : </b>La validation de la demande a détecté une valeur d'entrée du client potentiellement dangereuse et le traitement de la demande a été abandonné.  Cette valeur peut indiquer une tentative pour compromettre la sécurité de votre application, telle qu'une attaque de script entre sites.  Vous pouvez désactiver la validation de la demande en définissant validateRequest=false dans la directive de page ou dans la section de configuration <pages>.  Cependant, il est fortement recommandé que votre application contrôle explicitement toutes les entrées dans ce cas là.
            <br><br>

            <b> Détails de l'exception: </b>System.Web.HttpRequestValidationException: Une valeur Request.Form potentiellement dangereuse a &#233;t&#233; d&#233;tect&#233;e &#224; partir du client (DateDeb=&quot;&amp;#9731;&quot;).<br><br>

            <b>Erreur source:</b> <br><br>

            <table width=100% bgcolor="#ffffcc">
               <tr>
                  <td>
                      <code>

Une exception non g&#233;r&#233;e s'est produite lors de l'ex&#233;cution de la demande Web actuelle. Les informations relatives &#224; l'origine et l'emplacement de l'exception peuvent &#234;tre identifi&#233;es en utilisant la trace de la pile d'exception ci-dessous.</code>

                  </td>
               </tr>
            </table>

            <br>

            <b>Trace de la pile:</b> <br><br>

            <table width=100% bgcolor="#ffffcc">
               <tr>
                  <td>
                      <code><pre>

[HttpRequestValidationException (0x80004005): Une valeur Request.Form potentiellement dangereuse a &#233;t&#233; d&#233;tect&#233;e &#224; partir du client (DateDeb=&quot;&amp;#9731;&quot;).]
   System.Web.HttpRequest.ValidateString(String s, String valueName, String collectionName) +240
   System.Web.HttpRequest.ValidateNameValueCollection(NameValueCollection nvc, String collectionName) +99
   System.Web.HttpRequest.get_Form() +113
   System.Web.UI.Page.GetCollectionBasedOnMethod() +69
   System.Web.UI.Page.DeterminePostBackMode() +128
   System.Web.UI.Page.ProcessRequestMain() +2112
   System.Web.UI.Page.ProcessRequest() +217
   System.Web.UI.Page.ProcessRequest(HttpContext context) +18
   System.Web.CallHandlerExecutionStep.System.Web.HttpApplication+IExecutionStep.Execute() +179
   System.Web.HttpApplication.ExecuteStep(IExecutionStep step, Boolean&amp; completedSynchronously) +87
</pre></code>

                  </td>
               </tr>
            </table>

            <br>

            <hr width=100% size=1 color=silver>

            <b>Informations sur la version :</b>&nbsp;Version Microsoft .NET Framework :1.1.4322.2490; Version ASP.NET :1.1.4322.2494

            </font>

    </body>
</html>
